@@ -53,6 +53,11 @@ class NotFound(OSWinException):
     msg_fmt = _("Resource could not be found: %(resource)s")
 
 
+class PciDeviceNotFound(NotFound):
+    msg_fmt = _("No assignable PCI device with vendor id: %(vendor_id)s and "
+                "product id: %(product_id)s was found.")
+
+
 class HyperVException(OSWinException):
     pass
 
@@ -77,6 +82,15 @@ class HyperVPortNotFoundException(NotFound, HyperVException):
     msg_fmt = _("Switch port not found: %(port_name)s")
 
 
+class Invalid(OSWinException):
+    pass
+
+
+class InvalidParameterValue(Invalid):
+    msg_fmt = _("Invalid parameter value for: "
+                "%(param_name)s=%(param_value)s")
+
+
 class SMBException(OSWinException):
     pass
 
