@@ -23,12 +23,15 @@ from oslo_log import log as logging
 
 from os_win._i18n import _, _LW
 from os_win import _utils
+import os_win.conf
 from os_win import exceptions
 from os_win.utils.storage.initiator import fc_structures as fc_struct
 from os_win.utils import win32utils
 
+CONF = os_win.conf.CONF
+
 if sys.platform == 'win32':
-    hbaapi = ctypes.cdll.hbaapi
+    hbaapi = ctypes.cdll.LoadLibrary(CONF.os_win.hbaapi_lib_path)
 
 LOG = logging.getLogger(__name__)
 
@@ -140,7 +143,16 @@ class FCUtils(object):
 
         adapter_count = self.get_fc_hba_count()
         for adapter_index in range(adapter_count):
-            adapter_name = self._get_adapter_name(adapter_index)
+            # We'll ignore unsupported FC HBA ports.
+            try:
+                adapter_name = self._get_adapter_name(adapter_index)
+            except Exception as exc:
+                msg = _LW("Could not retrieve FC HBA adapter name for "
+                          "adapter number: %(adapter_index)s. "
+                          "Exception: %(exc)s")
+                LOG.warning(msg, dict(adapter_index=adapter_index, exc=exc))
+                continue
+
             try:
                 hba_ports += self._get_fc_hba_adapter_ports(adapter_name)
             except Exception as exc:
